@@ -8,6 +8,37 @@
 /*jsl:declare Ext*/
 /*jsl:declare _*/
 
+// Fix ExtJS 4.2.1 AbstractStore load behaviour: it sends the "sorters" array
+// to the server, even when "remoteSort" is false!
+// Note: this seems fixed in ExtJS 5 ProxyStore (in sencha-core package).
+
+Ext.define('MP.data.AbstractStore', {
+    override: 'Ext.data.AbstractStore',
+
+    load: function(options) {
+        var me = this,
+            operation;
+
+        options = Ext.apply({
+            action: 'read',
+            filters: me.filters.items
+        }, options);
+        if (me.remoteSort) {
+            options.sorters = me.getSorters();
+        }
+        me.lastOptions = options;
+
+        operation = new Ext.data.Operation(options);
+
+        if (me.fireEvent('beforeload', me, operation) !== false) {
+            me.loading = true;
+            me.proxy.read(operation, me.onProxyLoad, me);
+        }
+
+        return me;
+    }
+});
+
 /**
  * Maintain three lists, respectively for added, updated and deleted
  * records, so that the store can give an time ordered list of changes.
